@@ -42,7 +42,7 @@ $search_limit = $QueryResult->limit;
 
 try {
     // perform new query with data of previous query
-    $QueryResult = $Backend->query($Query,$startNum,$search_limit);
+    $QueryResult = $Backend->query($archive,$Query,$startNum,$search_limit);
     if ($QueryResult->found == 0) {
         $App->setMsg('MSG_NOTFOUND');
         $sessionMailId = '';
