@@ -226,6 +226,7 @@ class UserDA extends Persistence
 
     // private
     function _check_external_return($retvalue) {
+        global $App;
         $retlines = preg_split('/\n/',$retvalue);
         foreach ($retlines as $line) {
             $line = trim($line);
@@ -235,6 +236,9 @@ class UserDA extends Persistence
                 case 'ERROR':
                     throw new Exception($data);
                     break;
+                case 'WARN':
+                    $App->log('WARN '.$data,0);
+                    break;
                 case 'ROLE':
                     $this->role = $data;
                     break;
@@ -249,6 +253,16 @@ class UserDA extends Persistence
                     break;
                 case 'USERID':
                     $this->id = $data;
+                    break;
+                case 'RESTURL':
+                    $this->restdata['URL'] = $data;
+                    break;
+                case 'RESTUSER':
+                    $this->restdata['USER'] = $data;
+                    break;
+                case 'RESTPASS':
+                    $this->restdata['PASS'] = $data;
+                    break;
             }
         }
 
