@@ -98,7 +98,9 @@ $('a#bt_permalink').click(function(event){
 event.preventDefault();
 var url = $(this).attr("href");
 var input = $('#dialog_permalink input');
-input.val(window.location.href.split('?')[0]+url);
+var baseurl=window.location.href.split('?')[0];
+var dirname=baseurl.substr(0, baseurl.lastIndexOf("/"));
+input.val(dirname+'/'+url);
 });
 
 // Email Weiterleitung mit Enter bestätigen
